@@ -67,10 +67,6 @@ static BOOL  abortOnAwakeComponentInCtxDealloc = NO;
 static BOOL  abortOnMissingCtx                 = NO;
 static BOOL  wakeupPageOnCreation              = NO;
 
-+ (int)version {
-  // TODO: is really v4 for baseURL/cycleContext ivar changes
-  return [super version] + 0 /* v2 */;
-}
 + (void)initialize {
   NSUserDefaults  *ud;
   NGLoggerManager *lm;
@@ -78,10 +74,6 @@ static BOOL  wakeupPageOnCreation              = NO;
 
   if (didInit) return;
   didInit = YES;
-  
-  NSAssert2([super version] == 2,
-            @"invalid superclass (%@) version %i !",
-            NSStringFromClass([self superclass]), [super version]);
 
   ud = [NSUserDefaults standardUserDefaults];
   lm = [NGLoggerManager defaultLoggerManager];
@@ -166,6 +158,7 @@ static BOOL  wakeupPageOnCreation              = NO;
   [self->wocVariables  release];
   [self->wocName       release];
   [self->wocBaseURL    release];
+  [self->bundle        release];
   [super dealloc];
 }
 
@@ -357,10 +350,21 @@ static inline id _getExtraVar(WOComponent *self, NSString *_key) {
 - (NSString *)name {
   return self->wocName;
 }
+
+- (NSBundle *)componentBundle {
+  if (!self->bundle)
+    {
+      self->bundle = [NSBundle bundleForClass:[self class]];
+      [self->bundle retain];
+    }
+
+  return self->bundle;
+}
+
 - (NSString *)frameworkName {
   NSBundle *cbundle;
   
-  cbundle = [NGBundle bundleForClass:[self class]];
+  cbundle = [self componentBundle];
   if (cbundle == [NSBundle mainBundle])
     return nil;
   
