@@ -98,16 +98,9 @@ static NSNotificationCenter *getNC(void ) {
 }
 
 + (void)initialize {
-  NSAssert2([super version] == 1,
-            @"invalid superclass (%@) version %i !",
-            NSStringFromClass([self superclass]), [super version]);
-
   null = [[EONull null] retain];
   NSCalendarDateClass = [NSCalendarDate class];
 }
-+ (int)version {
-  return [super version] + 1; /* v2 */
-}
 
 - (id)initWithAdaptorName:(NSString *)_adName
   connectionDictionary:(NSDictionary *)_dict
@@ -252,7 +245,6 @@ static NSNotificationCenter *getNC(void ) {
   NSMutableString  *expression  = nil;
   NSMutableArray   *result      = nil;
   NSArray          *attrs       = nil;
-  EOAdaptor        *adaptor     = nil;
   NSArray          *pKeys       = nil;
   EOQualifier      *qual        = nil;
   EOAdaptorChannel *adChan      = nil;
@@ -313,7 +305,6 @@ static NSNotificationCenter *getNC(void ) {
   tz = [[self->fetchSpecification hints] objectForKey:EOFetchResultTimeZone];
     
   ASSIGN(self->__attributes, attrs);
-  adaptor = [[adChan adaptorContext] adaptor];
   {
     NSArray *a;
     NSSet *tableKeys     = nil;
