@@ -35,8 +35,8 @@ static BOOL       debugOn = NO;
   NSUserDefaults *ud = [NSUserDefaults standardUserDefaults];
   
   debugOn = [ud boolForKey:@"NGMimeGeneratorDebugEnabled"];
-  if (debugOn)
-    NSLog(@"WARNING[%@]: NGMimeGeneratorDebugEnabled is enabled!", self);
+  //if (debugOn)
+  //   NSLog(@"WARNING[%@]: NGMimeGeneratorDebugEnabled is enabled!", self);
   
   if (Pi == nil)
     Pi = [[NSProcessInfo processInfo] retain];
@@ -366,11 +366,18 @@ static BOOL       debugOn = NO;
     //       data which in turn resulted in a superflous "\r\n" string
     if ([headerData length] > 0) {
       [self->result appendData:headerData];
+
+      // We pad so our output buffer's with an extra \n\r to avoid Outlook data corruption.
+      // See: http://answers.microsoft.com/en-us/office/forum/office_2010-outlook/outlook-2010-decodes-pdf-attachment-as-all-zero/51012fe5-9d5e-431d-9d9c-a37b0171264a?page=2
+      // for more details.
       [self->result appendBytes:"\r\n" length:2];
     }
     
     if (bodyData != nil)
-      [self->result appendData:bodyData];
+      {
+        [self->result appendData:bodyData];
+        [self->result appendBytes:"\r\n" length:2];
+      }
     else if (debugOn)
       [self debugWithFormat:@"  => did not generate any body data!"];
   }
@@ -414,8 +421,7 @@ static BOOL       debugOn = NO;
 
   if (![[self generateMimeFromPart:_part]
               writeToFile:filename atomically:YES]) {
-    NSLog(@"ERROR[%s] couldn`t write data to temorary file %@",
-          __PRETTY_FUNCTION__, filename);
+    [self errorWithFormat: @"couldn`t write data to temorary file %@", filename];
     return nil;
   }
   return filename;
