@@ -942,7 +942,12 @@ static NSString *fieldNameForCString(id self, char *_cstring, int _len) {
   readB   = 0;
     
   buf = calloc(_len, sizeof(char));
-    
+  if (!buf)
+    {
+      [NSException raise: @"MIMEPartReadException" format: @"Can't alloc memory"];
+      return nil;
+    }
+
   NS_DURING {
 
     NS_DURING {
@@ -1125,7 +1130,7 @@ static NSString *fieldNameForCString(id self, char *_cstring, int _len) {
 
   rawBody = [self readBody];
 
-  /* apply content-encoding, transfer-encoding and similiar */
+  /* apply content-encoding, transfer-encoding and similar */
   rawBody = [self decodeBody:rawBody ofPart:_part];
 
   if (self->delegateRespondsTo.parserParseRawBodyDataOfPart) {
